#!/usr/bin/env python3
"""upload to scicat"""
import os
import pwd
import getpass
import datetime
import urllib

import requests

from scicat import api
from scicat import login


class Upload:
    """upload"""
    dataset = {}
    token = ""
    uri = ""
    delete_uri = ""

    def __init__(self):
        apix = api.Api()
        self.api = apix.api
        username = getpass.getuser()
        pwd_struct = pwd.getpwnam(username)
        print(pwd_struct)
        self.human_name = pwd_struct.pw_gecos
        split_name = pwd_struct.pw_gecos.split(' ')
        self.email = '.'.join(split_name) + "@esss.se"
        print(self.email)

    def create_json(self):
        """create json"""
        date = datetime.datetime.now().isoformat()
        self.dataset = {
            "pid": "xlfghz",
            "owner": self.human_name,
            "ownerEmail": self.email,
            "contactEmail": self.email,
            "sourceFolder": "/dram/",
            "datasetName": "Test python upload",
            "creationTime": date,
            "keywords": [
                "Test", "Derived", "Science"
            ],
            "description": "Test uploaded metadata from python",
            "isPublished": False,
            "ownerGroup": "p34123",
            "type": "raw"
        }

    def get_token(self):
        """get scicat token"""
        self.token = "uhY29G8F1YecRNzSoKeVqxRL5SfYciPxTO0u7ZB6lzyB3Urfv8GZSiSodvORNTkc"
        print(self.token)

    def create_uri(self):
        """create uri"""
        # login = Login()
        # token = login.login()
        self.uri = os.path.join(self.api, "Datasets") + \
            "?access_token=" + self.token
        print(self.uri)

    def upload_scicat(self):
        """upload to scicat"""
        self.get_token()
        self.create_uri()
        self.create_json()
        pid = urllib.parse.quote_plus("20.500.12269/"+self.dataset["pid"])
        delete_uri = os.path.join(
            self.api, "Datasets", pid) + "?access_token=" + self.token
        response = requests.delete(delete_uri)
        print(delete_uri)
        print(response.json())
        response = requests.post(self.uri, json=self.dataset)
        print(response.json())


def upload(name):
    """upload to scicat"""
    print("uploading to scicat")
    dataset = {
        "datasetName": name
    }
    uploader = Upload()
    uploader.upload_scicat()

    print(dataset)


def main():
    """main"""
    name = "nexus"
    upload(name)


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""attach a file"""
import os
import urllib

import requests

from scicat import login
from scicat import api
from scicat import base64_im


class Attach:
    """attach a file"""
    uri = ""
    api = ""

    def __init__(self):
        self.file = ""
        self.pid = ""
        self.token = ""
        self.attachment = {}
        apix = api.Api()
        self.api = apix.api

    def get_token(self):
        """get scicat token"""
        self.token = "uhY29G8F1YecRNzSoKeVqxRL5SfYciPxTO0u7ZB6lzyB3Urfv8GZSiSodvORNTkc"
        print(self.token)

    def create_uri(self):
        """create uri"""
        # login = Login()
        # token = login.login()
        pid_string = urllib.parse.quote_plus(self.pid)
        self.uri = os.path.join(self.api, "Datasets", pid_string, "attachments") + \
            "?access_token=" + self.token
        print(self.uri)

    def base64_encode(self):
        """base 64 encode"""

    def create_json(self):
        """create dict for attachment in scicat format"""
        base64im = base64_im.Base64Im()
        base64im.convert(self.file)

        file_string = base64im.image
        self.attachment = {
            "thumbnail": file_string,
            "caption": self.file,
            "datasetId": self.pid
        }

    def attach(self, file, pid):
        """attach a file"""
        self.file = file
        self.pid = pid
        self.get_token()
        self.create_uri()
        self.create_json()
        response = requests.post(self.uri, json=self.attachment)
        print(response.json())


def attach(file, pid):
    """attach a file"""
    attachment = Attach()
    attachment.attach(file, pid)


def main():
    """main"""
    file = "raw_data_3D_detectors.png"
    pid = "20.500.12269/xlfghz"
    attach(file, pid)


if __name__ == "__main__":
    main()



#!/usr/bin/env python3
"""login and get token"""
import os
import sys

import getpass
import requests
import keyring

from scicat import Api


class Login:
    """login and get token"""
    token = ""
    username = ""
    password = ""

    def login(self):
        """login and return token"""
        credentials = {}
        try:
            self.username = getpass.getuser()
            # username = username.replace(".", "")
            print("Username", self.username)
        except Exception as error:
            self.username = input("Username:")
        credentials["username"] = self.username
        password = keyring.get_password('scicat', self.username)
        if not password:
            print("No password found in keychain, please enter it now to store it.")
            password = getpass.getpass()
            keyring.set_password('scicat', self.username, password)
        credentials["password"] = password
        api = Api()
        url = os.path.join(api.base, "auth/msad")
        token = ""
        response = requests.post(url, json=credentials)
        result = response.json()
        print(result)
        token = ""
        if response.status_code == 200:
            pass
        else:
            print("Login failed")
            print(response.status_code)
            sys.exit()
        if isinstance(result, str):
            print("token", token)
        else:
            token = result.get("access_token")
            print("token", token)

        return token


def login():
    """main login"""
    scicatlogin = Login()
    scicatlogin.login()


if __name__ == "__main__":
    login()
